@@ -1741,7 +1741,8 @@ class Update(MethodsInterface):
             retval or Variable.EmptyTable, force=True)
 
         if not ignore_level:
-            best_binhost_level = int(sorted(self.clVars.Get("update.cl_update_binhost_level"), key=int)[-1])
+            best_binhost_level = int(self.clVars.Get("update.cl_update_binhost_level")[0])
+            #int(sorted(self.clVars.Get("update.cl_update_binhost_level"), key=int)[-1])
             # int(self.clVars.Get("update.cl_update_binhost_level")[0])
             
             if not current_level_is_valid:
@@ -1751,7 +1752,7 @@ class Update(MethodsInterface):
                 if cmpr > 0:
                     self.set_migration_mode(True)
                     #TODO reformulate, add translation
-                    raise UpdateError(_("Current level: {} Binhosts highest level: {}".\
+                    raise UpdateError(_("Current level: {} Binhost level: {}".\
                         format(self.clVars.Get("update.cl_update_level"), best_binhost_level)))
                 if cmpr < 0:
                     # self.clVars.Delete('update.cl_update_binhost_host', location="system")
